@@ -78,6 +78,7 @@ def make_vqsr_jobs(
     vqsr_params_d: Dict,
     scatter_count: int,
     output_vcf_path: str,
+    overwrite: bool,
 ) -> Job:
     """
     Add jobs that perform the allele-specific VQSR variant QC
@@ -183,7 +184,7 @@ def make_vqsr_jobs(
     huge_disk = 100 if is_small_callset else (500 if not is_huge_callset else 2000)
 
     combined_vcf_path = join(vqsr_bucket, 'input.vcf.gz')
-    if not utils.file_exists(combined_vcf_path):
+    if overwrite or not utils.file_exists(combined_vcf_path):
         mt_to_vcf_job = dataproc.hail_dataproc_job(
             b,
             f'{scripts_dir}/mt_to_vcf.py --overwrite '
@@ -419,8 +420,8 @@ def add_split_intervals_step(
     j.command(
         f"""set -e
 
-    # Modes other than INTERVAL_SUBDIVISION will produce an unpredicted number
-    # of intervals. But we have to expect exactly the {scatter_count} number of
+    # Modes other than INTERVAL_SUBDIVISION will produce an unpredictable number
+    # of intervals. But we have to produce exactly {scatter_count} number of
     # output files because our workflow is not dynamic.
     gatk --java-options -Xms{mem_gb - 1}g SplitIntervals \\
       -L {interval_list} \\
@@ -1080,8 +1081,16 @@ def _add_filter_sb_step(
     output_vcf_path: str = None,
 ) -> Job:
     """
-    Run VariantEval for site-level evaluation.
-    Saves the QC to `output_path` bucket
+    Removes the INFO/SB field from a VCF.
+
+    The reason we are doing that is because gatk ApplyVQSR replaces the VCF header
+    ##INFO=<ID=SB,Number=.,Type=Int,Description="Strand Bias">
+
+    with
+    ##INFO=<ID=SB,Number=1,Type=Float,Description="Strand Bias">
+
+    Even though the actual SB field is still a list of integers: SB=5,2,18,29
+    It breaks parsing the VCF into Hail.
     """
     j = b.new_job('Remove SB')
     j.image(utils.BCFTOOLS_DOCKER)
@@ -1093,8 +1102,7 @@ def _add_filter_sb_step(
 
     j.command(
         f"""
-    bcftools annotate -x INFO/SB {input_vcf['vcf.gz']} -Oz -o {j.output_vcf['vcf.gz']}
-    tabix {input_vcf['vcf.gz']}
+    bcftools annotate -x INFO/SB {input_vcf['vcf.gz']} -Oz -o {j.output_vcf['vcf.gz']} && tabix {j.output_vcf['vcf.gz']}
     """
     )
     if output_vcf_path:
